@@ -59,12 +59,6 @@ namespace libjami {
 
 MediaFrame::MediaFrame()
     : frame_ {av_frame_alloc()}
-    , packet_(nullptr, [](AVPacket* p) {
-        if (p) {
-            av_packet_unref(p);
-            delete p;
-        }
-    })
 {
     if (not frame_)
         throw std::bad_alloc();
@@ -94,7 +88,7 @@ MediaFrame::reset() noexcept
 }
 
 void
-MediaFrame::setPacket(std::unique_ptr<AVPacket, void (*)(AVPacket*)>&& pkt)
+MediaFrame::setPacket(PacketBuffer&& pkt)
 {
     packet_ = std::move(pkt);
 }
@@ -111,8 +105,7 @@ void
 AudioFrame::setFormat(const jami::AudioFormat& format)
 {
     auto d = pointer();
-    d->channels = format.nb_channels;
-    d->channel_layout = av_get_default_channel_layout(format.nb_channels);
+    av_channel_layout_default(&d->ch_layout, format.nb_channels);
     d->sample_rate = format.sample_rate;
     d->format = format.sampleFormat;
 }
@@ -121,7 +114,7 @@ jami::AudioFormat
 AudioFrame::getFormat() const
 {
     return {(unsigned) frame_->sample_rate,
-            (unsigned) frame_->channels,
+            (unsigned) frame_->ch_layout.nb_channels,
             (AVSampleFormat) frame_->format};
 }
 
@@ -149,7 +142,7 @@ AudioFrame::mix(const AudioFrame& frame)
 {
     auto& f = *pointer();
     auto& fIn = *frame.pointer();
-    if (f.channels != fIn.channels || f.format != fIn.format || f.sample_rate != fIn.sample_rate) {
+    if (f.ch_layout.nb_channels != fIn.ch_layout.nb_channels || f.format != fIn.format || f.sample_rate != fIn.sample_rate) {
         throw std::invalid_argument("Can't mix frames with different formats");
     }
     if (f.nb_samples == 0) {
@@ -160,8 +153,8 @@ AudioFrame::mix(const AudioFrame& frame)
     }
     AVSampleFormat fmt = (AVSampleFormat) f.format;
     bool isPlanar = av_sample_fmt_is_planar(fmt);
-    unsigned samplesPerChannel = isPlanar ? f.nb_samples : f.nb_samples * f.channels;
-    unsigned channels = isPlanar ? f.channels : 1;
+    unsigned samplesPerChannel = isPlanar ? f.nb_samples : f.nb_samples * f.ch_layout.nb_channels;
+    unsigned channels = isPlanar ? f.ch_layout.nb_channels : 1;
     if (fmt == AV_SAMPLE_FMT_S16 || fmt == AV_SAMPLE_FMT_S16P) {
         for (unsigned i = 0; i < channels; i++) {
             auto c = (int16_t*) f.extended_data[i];
@@ -192,8 +185,8 @@ AudioFrame::calcRMS() const
     double rms = 0.0;
     auto fmt = static_cast<AVSampleFormat>(frame_->format);
     bool planar = av_sample_fmt_is_planar(fmt);
-    int perChannel = planar ? frame_->nb_samples : frame_->nb_samples * frame_->channels;
-    int channels = planar ? frame_->channels : 1;
+    int perChannel = planar ? frame_->nb_samples : frame_->nb_samples * frame_->ch_layout.nb_channels;
+    int channels = planar ? frame_->ch_layout.nb_channels : 1;
     if (fmt == AV_SAMPLE_FMT_S16 || fmt == AV_SAMPLE_FMT_S16P) {
         for (int c = 0; c < channels; ++c) {
             auto buf = reinterpret_cast<int16_t*>(frame_->extended_data[c]);
@@ -216,7 +209,7 @@ AudioFrame::calcRMS() const
         return 0.0;
     }
     // divide by the number of multi-byte samples
-    return sqrt(rms / (frame_->nb_samples * frame_->channels));
+    return sqrt(rms / (frame_->nb_samples * frame_->ch_layout.nb_channels));
 }
 
 #ifdef ENABLE_VIDEO
