@@ -312,7 +312,7 @@ MediaEncoder::initStream(const SystemCodecInfo& systemCodecInfo, AVBufferRef* fr
                 JAMI_WARN("Using hardware encoding for %s with %s ",
                           avcodec_get_name(static_cast<AVCodecID>(systemCodecInfo.avcodecId)),
                           it.getName().c_str());
-                encoders_.push_back(encoderCtx);
+                encoders_.emplace_back(encoderCtx);
                 break;
             }
         }
@@ -326,7 +326,7 @@ MediaEncoder::initStream(const SystemCodecInfo& systemCodecInfo, AVBufferRef* fr
                                static_cast<AVCodecID>(systemCodecInfo.avcodecId),
                                videoOpts_.bitrate);
         readConfig(encoderCtx);
-        encoders_.push_back(encoderCtx);
+        encoders_.emplace_back(encoderCtx);
         if (avcodec_open2(encoderCtx, outputCodec_, &options_) < 0)
             throw MediaEncoderException("Could not open encoder");
     }
@@ -495,6 +495,8 @@ MediaEncoder::encode(AVFrame* frame, int streamIdx)
         }
     }
     int ret = 0;
+    if (streamIdx >= encoders_.size())
+        return -1;
     AVCodecContext* encoderCtx = encoders_[streamIdx];
     AVPacket pkt;
     av_init_packet(&pkt);
@@ -641,14 +643,11 @@ MediaEncoder::prepareEncoderContext(const AVCodec* outputCodec, bool is_video)
         encoderCtx->sample_rate = std::max(8000, audioOpts_.sampleRate);
         encoderCtx->time_base = AVRational {1, encoderCtx->sample_rate};
         if (audioOpts_.nbChannels > 2 || audioOpts_.nbChannels < 1) {
-            encoderCtx->channels = std::clamp(audioOpts_.nbChannels, 1, 2);
+            audioOpts_.nbChannels = std::clamp(audioOpts_.nbChannels, 1, 2);
             JAMI_ERR() << "[" << encoderName
-                       << "] Clamping invalid channel count: " << audioOpts_.nbChannels << " -> "
-                       << encoderCtx->channels;
-        } else {
-            encoderCtx->channels = audioOpts_.nbChannels;
+                       << "] Clamping invalid channel count: " << audioOpts_.nbChannels;
         }
-        encoderCtx->channel_layout = av_get_default_channel_layout(encoderCtx->channels);
+        av_channel_layout_default(&encoderCtx->ch_layout, audioOpts_.nbChannels);
         if (audioOpts_.frameSize) {
             encoderCtx->frame_size = audioOpts_.frameSize;
             JAMI_DBG() << "[" << encoderName << "] Frame size " << encoderCtx->frame_size;
