@@ -307,12 +307,6 @@ CurrentConversation::connectModel()
             Qt::UniqueConnection);
 }
 
-void
-CurrentConversation::showSwarmDetails()
-{
-    Q_EMIT showDetails();
-}
-
 void
 CurrentConversation::updateErrors(const QString& convId)
 {
