@@ -759,3 +759,18 @@ UtilsAdapter::getOneline(const QString& input)
         output.truncate(index);
     return output;
 }
+
+QVariantMap
+UtilsAdapter::getVideoPlayer(const QString& resource, const QString& bgColor)
+{
+    static const QString htmlVideo
+        = "<body style='margin:0;padding:0;'>"
+          "<video autoplay muted loop "
+          "style='width:100%;height:100%;outline:none;background-color:%2;"
+          "object-fit:cover;' "
+          "src='%1' type='video/webm'/></body>";
+    return {
+        {"isVideo", true},
+        {"html", htmlVideo.arg(resource, bgColor)},
+    };
+}
